intelmq.bots.experts.recordedfuture_iprisk package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.recordedfuture_iprisk package

## Submodules

## intelmq.bots.experts.recordedfuture_iprisk.expert module

See README for database download.

intelmq.bots.experts.recordedfuture_iprisk.expert.BOT

  alias of `intelmq.bots.experts.recordedfuture_iprisk.expert.RecordedFutureIPRiskExpertBot`

class intelmq.bots.experts.recordedfuture_iprisk.expert.RecordedFutureIPRiskExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`

  Adds the Risk Score from RecordedFuture IPRisk associated with source.ip or destination.ip with a local database

  api_token: str = '<insert Recorded Future IPRisk API token>'
  database: str = '/opt/intelmq/var/lib/bots/recordedfuture_iprisk/rfiprisk.dat'
  init()
  overwrite: bool = False
  process()
  classmethod run(parsed_args=None)
  classmethod update_database(verbose=False)

## Module contents